;; Generated package description from org-modern.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "org-modern" "1.15.0.20260818.3" "Modern looks for Org" '((emacs "29.1") (org "9.6") (compat "31")) :commit "d106d02cf045cc968c09989e9c48e0f2b44c574c" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("outlines" "hypermedia" "text") :url "https://github.com/minad/org-modern")
